@@ -13,6 +13,11 @@ from aasrp.utils import clean_setting
 # AA-GDPR
 AVOID_CDN = clean_setting("AVOID_CDN", False)
 
+# SRP Team Discord Channel
+AASRP_SRP_TEAM_DISCORD_CHANNEL = clean_setting(
+    name="AASRP_SRP_TEAM_DISCORD_CHANNEL", default_value=None, required_type=int
+)
+
 
 def get_site_url() -> str:  # regex sso url
     """
